%% Computing meltwater flux from shear margins

% Here we estimate effective pressure and effective porosity, and then meltware flux from shear margins 
clear all;
close all;

% top-level parameters
theta = 1;
%H = 200;
H = 1000;
%num_pts = 256;
num_pts = 100;
z = linspace(0,H,num_pts);
z = z./H; % non dimensionalize

% thermomechanical parameters
%Tm = 273;
%Ts = 248;
Tm = 273.15;
%Ts = 273.15-1;
Ts = 273.15-25;
dT = Tm-Ts;
K = 2.1; % W m^-1 K^-1
%cp = 2009; % J kg^-1 K^-1
cp = 2050; % J kg^-1 K^-1

% rheological parameters
n = 3;
A = 2.4e-24; % Pa^-3 s^-1

% temperate-related parameters
kappa = 1;
alpha = 2.5;
%kappa = 0.4416;
%alpha = 2;
N0 = 1;
delta = 0.0023;
rho_water = 1000; % kg m^-3
rho_ice = 916; % kg m^-3;

% input parameters
Br = [6, 10, 20];
Pe = 2.15;
%Br = 22.4919;
%Pe = 1.1115;

% initialize everything
T = zeros(length(Br),length(z));
porosity_outer = zeros(length(Br),length(z));
effpressure_outer = zeros(length(Br),length(z));
porosity_inner_0 = zeros(length(Br),length(z));
effpressure_comp = zeros(length(Br),length(z));
porosity_inner_1 = zeros(length(Br),length(z));
porosity_inner = zeros(length(Br),length(z));
flux = zeros(length(Br),length(z));

for i=1:length(Br)
    [T(i,:),zct(i),sr,crit_sr] = findIceTemperature(Br(i),Pe,theta,H,z,Tm,Ts,K,A,n,dT);
    zct(i) = zct(i)./H; % non dimensionalize 
    [porosity_outer(i,:)] = findOuterPorosityProfile(-Pe,Br(i),zct(i),z,kappa,alpha);
    [effpressure_outer(i,:)] = findOuterPressureProfile(Br(i),-Pe,porosity_outer(i,:),kappa,alpha);
    [porosity_inner_0(i,:)] = findInnerPorosity0Profile(porosity_outer(i,1));
    [effpressure_comp(i,:)] = findInnerPressureProfile(effpressure_outer(i,:),N0,alpha,kappa,-Pe,porosity_outer(i,:),z,zct(i),delta);
    [porosity_inner_1(i,:)] = findInnerPorosity1Profile(Br(i),-Pe,porosity_outer(i,:),effpressure_comp(i,:),z,zct(i),delta);
    [porosity_inner(i,:)] = findInnerPorosityProfile(porosity_outer(i,:),porosity_inner_1(i,:),delta,z,zct(i));
    [flux(i,:)] = findMeltwaterFlux(porosity_inner(i,:),alpha,kappa,effpressure_comp(i,:),z,delta);
end

% plotting
cmap = colorcet('l10','N',3,'reverse',0);

figure;
subplot(2,2,1)
for i=1:length(Br)
    plot((T(i,:)-Tm)./dT,z,'LineWidth',2,'Color',cmap(i,:))
    %plot(T(i,:),z,'LineWidth',2,'Color',cmap(i,:))
    hold on
end
grid on
colormap(cmap)
xlabel('Temperature')
ylabel('Height')
xlim([-1 0])
ylim([0 1])
set(gca,'FontSize',12,'FontWeight','b','GridColor','r');
legend('Br = 6','Br = 10','Br = 20','location','southwest')

subplot(2,2,2)
for i=1:length(Br)
    plot(effpressure_comp(i,:),z,'LineWidth',2,'Color',cmap(i,:))
    hold on
    plot(effpressure_outer(i,:),z,'--','LineWidth',2,'Color',cmap(i,:))
end
grid on
colormap(cmap)
xlabel('N')
%xlim([0 12])
%xticks([0 2 4 6 8 10 12])
ylim([0 1])
set(gca,'FontSize',12,'FontWeight','b','GridColor','r');
legend('Inner Solution','Outer Solution')

subplot(2,2,3)
for i=1:length(Br)
    plot(porosity_inner(i,:),z,'LineWidth',2,'Color',cmap(i,:))
    hold on
    plot(porosity_outer(i,:),z,'--','LineWidth',2,'Color',cmap(i,:))
end
grid on
colormap(cmap)
xlabel('Porosity (%)')
ylabel('Height')
xlim([0 3])
xticks([0 0.5 1 1.5 2 2.5 3])
ylim([0 1])
set(gca,'FontSize',12,'FontWeight','b','GridColor','r');
%legend('Inner Solution','Outer Solution','Numerics')

subplot(2,2,4)
for i=1:length(Br)
    plot(flux(i,:),z,'LineWidth',2,'Color',cmap(i,:))
    hold on
end
grid on
colormap(cmap)
xlabel('Flux')
xlim([-12 4])
xticks([-12 -10 -8 -6 -4 -2 0 2 4])
ylim([0 1])
set(gca,'FontSize',12,'FontWeight','b','GridColor','r');
